@@ -9,7 +9,7 @@ import sunpy.lightcurve
 from sunpy.time import TimeRange
 
 
-class TestGOESLightCurve():
+class TestGOESLightCurve(object):
 
     @pytest.fixture
     def timerange_a(self):
@@ -22,7 +22,7 @@ class TestGOESLightCurve():
     @pytest.mark.online
     def test_goes_range(self, timerange_a):
         """Test creation with two times"""
-        lc1 = sunpy.lightcurve.GOESLightCurve.create(timerange_a.start(), timerange_a.end())
+        lc1 = sunpy.lightcurve.GOESLightCurve.create(timerange_a.start, timerange_a.end)
         assert isinstance(lc1, sunpy.lightcurve.GOESLightCurve)
 
     @pytest.mark.online
@@ -81,8 +81,8 @@ class TestGOESLightCurve():
     def test_goes_sat_numbers(self, timerange_a, timerange_b):
         """Test the ability to return GOES satellite availability"""
         g = sunpy.lightcurve.GOESLightCurve
-        assert g._get_goes_sat_num(timerange_a.start(), timerange_a.end()) == [10]
-        assert g._get_goes_sat_num(timerange_b.start(), timerange_b.end()) == [7]
+        assert g._get_goes_sat_num(timerange_a.start, timerange_a.end) == [10]
+        assert g._get_goes_sat_num(timerange_b.start, timerange_b.end) == [7]
 
     def test_get_url(self, timerange_a, timerange_b):
         """Test the getting of urls"""
