@@ -25,9 +25,15 @@ def load_config():
     if not config.has_option('general', 'working_dir'):
         config.set('general', 'working_dir', os.path.join(_get_home(), "sunpy"))
 
+    # Specify the database url as a default so that the user's home
+    # directory can be located in an OS-independent manner
+    if not config.has_option('database', 'url'):
+        config.set('database', 'url', "sqlite:///" + os.path.join(_get_home(), "sunpy/sunpydb.sqlite"))
+
     # Use absolute filepaths and adjust OS-dependent paths as needed
     filepaths = [
-        ('downloads', 'download_dir')
+        ('downloads', 'download_dir'),
+        ('downloads', 'sample_dir')
     ]
     _fix_filepaths(config, filepaths)
 
@@ -35,6 +41,9 @@ def load_config():
     if not os.path.isdir(config.get('downloads', 'download_dir')):
         os.mkdir(config.get('downloads', 'download_dir'))
 
+    if not os.path.isdir(config.get('downloads', 'sample_dir')):
+        os.mkdir(config.get('downloads', 'sample_dir'))
+
     return config
 
 def print_config():
@@ -45,9 +54,9 @@ def print_config():
 
     print ("\nCONFIGURATION:")
     for section in spy.config.sections():
-        print("  [%s]" % section)
+        print("  [{0}]".format(section))
         for option in spy.config.options(section):
-            print("  %s = %s" % (option, spy.config.get(section, option)))
+            print("  {0} = {1}".format(option, spy.config.get(section, option)))
         print("")
 
 def _is_writable_dir(p):
@@ -84,7 +93,7 @@ def _find_config_files():
     config_files.append(os.path.join(module_dir, 'data', 'sunpyrc'))
 
     # if a user configuration file exists, add that to list of files to read
-    # so that any values set there will overide ones specified in the default
+    # so that any values set there will override ones specified in the default
     # config file
     config_path = _get_user_configdir()
 
@@ -103,8 +112,8 @@ def _get_user_configdir():
 
     if configdir is not None:
         if not _is_writable_dir(configdir):
-            raise RuntimeError('Could not write to SUNPY_CONFIGDIR="%s"' %
-                               configdir)
+            raise RuntimeError('Could not write to SUNPY_CONFIGDIR="{0}"'.format(
+                               configdir))
         return configdir
 
     h = _get_home()
@@ -112,16 +121,16 @@ def _get_user_configdir():
 
     if os.path.exists(p):
         if not _is_writable_dir(p):
-            raise RuntimeError("'%s' is not a writable dir; you must set %s/."
+            raise RuntimeError("'{0}' is not a writable dir; you must set {1}/."
                                "sunpy to be a writable dir.  You can also set "
                                "environment variable SUNPY_CONFIGDIR to any "
                                "writable directory where you want matplotlib "
-                               "data stored " % (h, h))
+                               "data stored ".format(h, h))
     else:
         if not _is_writable_dir(h):
-            raise RuntimeError("Failed to create %s/.sunpy; consider setting "
+            raise RuntimeError("Failed to create {0}/.sunpy; consider setting "
                                "SUNPY_CONFIGDIR to a writable directory for "
-                               "sunpy configuration data" % h)
+                               "sunpy configuration data".format(h))
 
         os.mkdir(p)
 
